@@ -96,5 +96,7 @@ class Gateway():
 if __name__ == '__main__':
     gateway = Gateway('modbus.local', 5020, 1)
     a = gateway._Machine
+    print (a.get_zones()[0].is_zone)
+    a.get_zones()[0].turnoff_zone()
     #gateway.init_polling()
 
